Built-in Nonlinear Models
=========================

Factory functions that return :class:`~dynaris.core.nonlinear.NonlinearSSM`
instances for well-known nonlinear state-space models.

Stochastic Volatility
---------------------

.. autofunction:: dynaris.models.StochasticVolatility

.. autofunction:: dynaris.models.transform_returns

Bearings-Only Tracking
----------------------

.. autofunction:: dynaris.models.BearingsTracking

Lorenz Attractor
----------------

.. autofunction:: dynaris.models.LorenzAttractor
